// ---------------------------------------------------------------------------
// FormUrlList.c
// Contains PalmOS specific code, for URLs form
// 
// Project: WAPUniverse for PalmOS
// Copyright  1999-2000 Filip Onkelinx
//
// http://www.wapuniverse.com/
// filip@onkelinx.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
//
// 
// $Workfile: formUrlList.c $  
// $Author: wapuniverse $  
// $Date: 2000/11/11 20:51:09 $     
// $Revision: 1.7 $
// 
// $Header: /cvsroot/wapuniverse/wapuniverse/src/formUrlList.c,v 1.7 2000/11/11 20:51:09 wapuniverse Exp $
// 
// -------------------------------------------------------------------------------

#include    <PalmOS.h>
#include    <SysEvtMgr.h>
#include 	"WAPUniverse.h"
#include	"DbUrl.h"
#include    "formUrlList.h"
#include 	"PalmUtils.h"
#include 	"../res/WAPUniverse_res.h"
#include    "MenuHnd.h"
#ifdef __GNUC__
#include "callbacks.h"
#endif


static Boolean ButtonOpen_OH(EventPtr event, GlobalsType *g) SEC_1; 	/* Button */
static Boolean ButtonNew_OH(EventPtr event, GlobalsType *g) SEC_1; 	/* Button */
static Boolean ButtonEdit_OH(EventPtr event, GlobalsType *g) SEC_1; 	/* Button */
static Boolean URLsCategoryTrigger_OH(EventPtr event, GlobalsType *g) SEC_1; 	/* Pop-up Trigger */
static Boolean ListURL_OH(EventPtr event) SEC_1; 	/* List */
static Boolean CategoriesList_OH(EventPtr event) SEC_1; 	/* List */
static void DrawOneURLInList (Int16 itemNumber, RectangleType *bounds, Char * * text) SEC_1;
static void InitViewURLs (GlobalsType *g) SEC_1;

static void
DrawOneURLInList (Int16 itemNumber, RectangleType *bounds, Char * * text)
{
  MemHandle         h;
  void	            *p =NULL;
  Int16             seekAmount = itemNumber;
  UInt16            index = 0;
  GlobalsType		*g;
  
#ifdef __GNUC__
  CALLBACK_PROLOGUE
#endif

  FtrGet(wuAppType, ftrGlobals, (UInt32 *)&g);

  // must do seek to skip over secret records
    DmSeekRecordInCategory (g->DbUrlDb, &index, seekAmount, dmSeekForward, g->DbUrlCurrentCategory);
  h = DmQueryRecord (g->DbUrlDb, index);
  if (h)
    {
      dbUrlPackedURL*      packedURL = MemHandleLock (h);
      dbUrlURL 	  url;
      dbUrlUnPackURL (&url, packedURL);
      p = (void *)packedURL;
      DrawCharsToFitWidth (url.name, bounds, ' ');
      if (p){
      	MemPtrUnlock (p);
      }
    }
#ifdef __GNUC__
  CALLBACK_EPILOGUE
#endif
}

static void
InitViewURLs (GlobalsType *g)
{

  FormPtr         frm = FrmGetActiveForm ();
  ListPtr         list = FrmGetObjectPtr (frm, FrmGetObjectIndex (frm, listUrlList));
  UInt16            numURLs = DmNumRecordsInCategory (g->DbUrlDb, g->DbUrlCurrentCategory);
  LstSetListChoices (list, NULL, numURLs);
  LstSetDrawFunction (list, DrawOneURLInList);

  enableUrlEditOpen(g);
  CategoryGetName (g->DbUrlDb, g->DbUrlCurrentCategory, g->DbUrlCategoryName);
  CategorySetTriggerLabel (GetObjectPtr (triggerUrlListCategory), g->DbUrlCategoryName);
}

void enableUrlEditOpen(GlobalsType *g)
{
  FormPtr	frm;
  Boolean 	enable;
  
    if (dbUrlNumRecords(g) >0)
		enable = true;
	else
		enable = false;
    frm = FrmGetFormPtr (frmUrlList);
    CtlSetEnabled(FrmGetObjectPtr (frm, FrmGetObjectIndex (frm, buttonOpen)),enable);
  	CtlSetEnabled(FrmGetObjectPtr (frm, FrmGetObjectIndex (frm, buttonEdit)),enable);
    CtlSetUsable(FrmGetObjectPtr (frm, FrmGetObjectIndex (frm, buttonOpen)),enable);
  	CtlSetUsable(FrmGetObjectPtr (frm, FrmGetObjectIndex (frm, buttonEdit)),enable);
	
}


/**----------------------------------**/
/** Form Event Handler for FormURLs**/
/**----------------------------------**/

/****************************************************/
/* 
   Function: Boolean FormURLs_EH(EventPtr event);
   Description: Main Form Event Handler for FormURLs
 */
/****************************************************/


/* Form Event Handler */
Boolean
ehFormUrlList(EventPtr event)
{
    Boolean handled = false;
	GlobalsType *g;

#ifdef __GNUC__
    CALLBACK_PROLOGUE
#endif

  	FtrGet(wuAppType, ftrGlobals, (UInt32 *)&g);
    switch(event->eType) {

        case ctlSelectEvent:
            if (event->data.ctlSelect.controlID == buttonOpen) {
                ButtonOpen_OH(event,g); }
            if (event->data.ctlSelect.controlID == buttonNew) {
                ButtonNew_OH(event,g); }
            if (event->data.ctlSelect.controlID == buttonEdit) {
                ButtonEdit_OH(event,g); }
            if (event->data.ctlSelect.controlID == buttonViewU) {
                SwitchForm(frmConnectionList,g); }
            if (event->data.ctlSelect.controlID == buttonInfoU) {
                DisplayAbout(); }
            if (event->data.ctlSelect.controlID == triggerUrlListCategory) {
                URLsCategoryTrigger_OH(event,g); }
            break;

        case lstSelectEvent:
        case popSelectEvent:
            if (event->data.ctlSelect.controlID == triggerUrlListCategory) {
                URLsCategoryTrigger_OH(event,g); }
            if (event->data.ctlSelect.controlID == listUrlList) {
                ListURL_OH(event); }
            if (event->data.ctlSelect.controlID == listCategoriesList) {
                CategoriesList_OH(event); }
            break;

        case frmOpenEvent:
           InitViewURLs(g);
           FrmDrawForm(FrmGetActiveForm());
           handled = true;
           break;

        case menuEvent:
           mhMenuOptions(event->data.menu.itemID,g);
           break;
	
   	   default:
	   break;

           }
#ifdef __GNUC__
    CALLBACK_EPILOGUE
#endif
    return handled;
}


/* Item Handler Functions Here */

/**--------------------------------------**/
/** Form Object Handler Functions for FormURLs **/
/**--------------------------------------**/

/****************************************************/
/* 
   Function: Boolean ButtonOpen_OH(EventPtr event);
   Description: Button Object Handler for the FormURLs Form
 */
/****************************************************/

static Boolean ButtonOpen_OH(EventPtr event, GlobalsType *g)
{
 FormPtr  frm;
 
   frm = FrmGetActiveForm ();
   g->DbUrlCurrentRecord = LstGetSelection (FrmGetObjectPtr (frm,
                                       FrmGetObjectIndex(frm, listUrlList)));
   g->CurrentView = frmBrowser;
   FrmGotoForm (g->CurrentView);
	return(true);
}


/****************************************************/
/* 
   Function: Boolean ButtonNew_OH(EventPtr event);
   Description: Button Object Handler for the FormURLs Form
 */
/****************************************************/

static Boolean ButtonNew_OH(EventPtr event, GlobalsType *g)
{
    dbUrlCreateRecord (g);
    g->CurrentView = frmEditURL;
    FrmGotoForm (g->CurrentView);
	enableUrlEditOpen(g);
	return(true);
}


/****************************************************/
/* 
   Function: Boolean ButtonEdit_OH(EventPtr event);
   Description: Button Object Handler for the FormURLs Form
 */
/****************************************************/

static Boolean ButtonEdit_OH(EventPtr event, GlobalsType *g)
{
FormPtr frm;

   frm = FrmGetActiveForm ();
   g->DbUrlCurrentRecord = LstGetSelection (FrmGetObjectPtr (frm,
                                        FrmGetObjectIndex(frm, listUrlList)));
   g->CurrentView = frmEditURL;
   FrmGotoForm (g->CurrentView);
   enableUrlEditOpen(g);
   return(true);
}

/****************************************************/
/* 
   Function: Int16 URLsCategoryTrigger_OH(EventPtr event);
   Description: Pop-up Trigger Object Handler for the FormURLs Form
 */
/****************************************************/

static Boolean URLsCategoryTrigger_OH(EventPtr event, GlobalsType *g)
{
    if (CategorySelect (g->DbUrlDb, FrmGetActiveForm (),
                              triggerUrlListCategory, listCategoriesList,
                              true, &(g->DbUrlCurrentCategory), g->DbUrlCategoryName, 1, 0))
      {
              g->NewCategoryEdited = true;
      }
    InitViewURLs (g);
    FrmDrawForm (FrmGetActiveForm ());
	return(true);
}


/****************************************************/
/* 
   Function: Int16 ListURL_OH(EventPtr event);
   Description: List Object Handler for the FormURLs Form
 */
/****************************************************/

static Boolean ListURL_OH(EventPtr event)
{

	return(true);
}


/****************************************************/
/* 
   Function: Int16 CategoriesList_OH(EventPtr event);
   Description: List Object Handler for the FormURLs Form
 */
/****************************************************/

static Boolean CategoriesList_OH(EventPtr event)
{

	return(true);
}


